bayespy.inference.vmp.nodes.dirichlet.DirichletDistribution.compute_moments_and_cgf
===================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.dirichlet

.. automethod:: DirichletDistribution.compute_moments_and_cgf